@@ -153,6 +153,15 @@ class OriginADBDevice(_BaseADBDevice):
     def am_kill(self, package_name: str, *options) -> str:
         return self.shell(["am", "kill", *options, package_name])
 
+    def am_start(self, package_name: str, *options) -> str:
+        return self.shell(["am", "start", *options, package_name])
+
+    def am_instrument(self, args: typing.Union[str, list], no_wait: bool = None) -> str:
+        prefix = ["am", "instrument"]
+        if isinstance(args, list):
+            return self.shell([*prefix, *args], no_wait=no_wait)
+        return self.shell(" ".join(prefix) + " " + args, no_wait=no_wait)
+
     def pm_clear(self, package_name: str) -> str:
         return self.shell(["pm", "clear", package_name])
 
@@ -312,6 +321,43 @@ class ADBDevice(OriginADBDevice):
             *self.ratio2position(*point_dict[to]),
         )
 
+    def screenshot(self, to_sdcard: str = None, to_pc: str = None):
+        sdcard_path = r"/data/local/tmp/minadb_shot.png"
+        if to_sdcard:
+            sdcard_path = to_sdcard
+
+        self.shell(["screencap", "-p", sdcard_path])
+        if to_pc:
+            self.pull(sdcard_path, to_pc)
+
+    def play_audio(self, source_path: str) -> str:
+        return self.shell(
+            [
+                "am",
+                "start",
+                "-a",
+                "android.intent.action.VIEW",
+                "-t",
+                "audio/mp3",
+                "-d",
+                f"file://{source_path}",
+            ]
+        )
+
+    def play_video(self, source_path: str) -> str:
+        return self.shell(
+            [
+                "am",
+                "start",
+                "-a",
+                "android.intent.action.VIEW",
+                "-t",
+                "video/*",
+                "-d",
+                f"file://{source_path}",
+            ]
+        )
+
     # alias
     tap = click = OriginADBDevice.input_tap
     swipe = OriginADBDevice.input_swipe
@@ -324,3 +370,5 @@ class ADBDevice(OriginADBDevice):
     set_wifi = OriginADBDevice.svc_wifi
     is_installed = is_package_installed
     press_recent = press_switch = press_menu
+    screencap = screenshot
+    play_music = play_audio
